Welcome to Artist's documentation!
==================================

Artist is a 2D plotting library for Python.  It's main focus is the
output.  Artist creates a LaTeX file which can be included in your paper
or thesis.  The code needs TikZ and PGFPlots to compile and your plots
will tightly integrate with your main text.  Artist provides an
easy-to-use and clean Python interface and can compile your plot
on-the-fly as a stand-alone PDF file.

A pdf containing some examples can be downloaded here:
`Demo plots (pdf) <demo_plots.pdf>`_.

**Contents**:

.. toctree::
   :maxdepth: 2

   introduction
   tutorial
   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

